Optional Settings — django-frontend 1.3.0 documentation

### Navigation

- index
- next |
- previous |
- django-frontend 1.3.0 documentation »

# Optional Settings

For greater granularity, you can optionally set versions of included files through your settings.

Settings are overridden if also set within a template.

## DJFRONTEND_STATIC_URL

Set a dedicated static server or CDN for serving static files.

## DJFRONTEND_H5BP_HTML

Sets the lang attribute value.

## DJFRONTEND_H5BP_CSS

Sets the version of the HTML5 Boilerplate CSS file.

## DJFRONTEND_NORMALIZE

Sets the version of the Normalize CSS file.

## DJFRONTEND_FONTAWESOME

Sets the version of the Font Awesome CSS file.

## DJFRONTEND_MODERNIZR

Sets the version of the Modernizr JavaScript file.

## DJFRONTEND_JQUERY

Sets the version of the jQuery JavaScript file.

## DJFRONTEND_JQUERYUI

Sets the version of the jQuery UI file.

## DJFRONTEND_JQUERY_DATATABLES_VERSION

Sets the version of the jQuery DataTables JavaScript and CSS file. Can be overridden by ‘DJFRONTEND_JQUERY_DATATABLES’ or ‘DJFRONTEND_JQUERY_DATATABLES_CSS’.

## DJFRONTEND_JQUERY_DATATABLES

Sets the version of the jQuery DataTables JavaScript file.

## DJFRONTEND_JQUERY_DATATABLES_CSS

Sets the version of the jQuery DataTables CSS file.

## DJFRONTEND_JQUERY_FORMSET

Sets the version of the jQuery Dynamic Formset JavaScript file.

## DJFRONTEND_JQUERY_SCROLLTO

Sets the version of the jQuery ScrollTo JavaScript file.

## DJFRONTEND_JQUERY_SMOOTHSCROLL

Sets the version of the jQuery SmoothScroll JavaScript file.

## DJFRONTEND_TWBS_VERSION

Sets the version of Twitter Bootstrap’s JavaScript and CSS file(s). Can be overridden by ‘DJFRONTEND_TWBS_CSS’, ‘DJFRONTEND_TWBS_THEME_CSS’ or ‘DJFRONTEND_TWBS_JS_VERSION’.

## DJFRONTEND_TWBS_CSS

Sets the version of the Twitter Bootstrap CSS file.

## DJFRONTEND_TWBS_THEME_CSS

Sets the version of the Twitter Bootstrap Theme CSS file.

## DJFRONTEND_TWBS_JS_VERSION

Sets the version of the Twitter Bootstrap JavaScript file(s).

## DJFRONTEND_TWBS_JS_FILES

Sets the Twitter Bootstrap JavaScript file(s).

## DJFRONTEND_GA

Sets the Google Analtyics account.

## DJFRONTEND_GA_SETDOMAINNAME

Set domain for multiple, or cross-domain tracking with Google Analytics.

## DJFRONTEND_GA_SETALLOWLINKER

To use _setAllowLinker method on target site for cross-domain tracking with Google Analytics. Set to ‘True’ to enable. Requires H5BP_GA_SETDOMAINNAME to be set.

### Navigation

- index
- next |
- previous |
- django-frontend 1.3.0 documentation »